summaryrefslogtreecommitdiffstats
path: root/kmail/headeritem.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kmail/headeritem.cpp
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/headeritem.cpp')
-rw-r--r--kmail/headeritem.cpp50
1 files changed, 25 insertions, 25 deletions
diff --git a/kmail/headeritem.cpp b/kmail/headeritem.cpp
index 684dd590..230b6499 100644
--- a/kmail/headeritem.cpp
+++ b/kmail/headeritem.cpp
@@ -16,11 +16,11 @@
**
** In addition, as a special exception, the copyright holders give
** permission to link the code of this program with any edition of
-** the Qt library by Trolltech AS, Norway (or with modified versions
-** of Qt that use the same license as Qt), and distribute linked
+** the TQt library by Trolltech AS, Norway (or with modified versions
+** of TQt that use the same license as TQt), and distribute linked
** combinations including the two. You must obey the GNU General
** Public License in all respects for all of the code used other than
-** Qt. If you modify this file, you may extend this exception to
+** TQt. If you modify this file, you may extend this exception to
** your version of the file, but you are not obligated to do so. If
** you do not wish to do so, delete this exception statement from
** your version.
@@ -42,8 +42,8 @@
using namespace KMail;
// Constuction a new list view item with the given colors and pixmap
-HeaderItem::HeaderItem( TQListView* parent, int msgId, const TQString& key )
- : KListViewItem( parent ),
+HeaderItem::HeaderItem( TQListView* tqparent, int msgId, const TQString& key )
+ : KListViewItem( tqparent ),
mMsgId( msgId ),
mKey( key ),
mAboutToBeDeleted( false ),
@@ -52,9 +52,9 @@ HeaderItem::HeaderItem( TQListView* parent, int msgId, const TQString& key )
irefresh();
}
-// Constuction a new list view item with the given parent, colors, & pixmap
-HeaderItem::HeaderItem( TQListViewItem* parent, int msgId, const TQString& key )
- : KListViewItem( parent ),
+// Constuction a new list view item with the given tqparent, colors, & pixmap
+HeaderItem::HeaderItem( TQListViewItem* tqparent, int msgId, const TQString& key )
+ : KListViewItem( tqparent ),
mMsgId( msgId ),
mKey( key ),
mAboutToBeDeleted( false ),
@@ -92,7 +92,7 @@ void HeaderItem::irefresh()
return; //default to closed
// otherwise threadingPolicy == OpenUnread
- if (parent() && parent()->isOpen()) {
+ if (tqparent() && tqparent()->isOpen()) {
setOpen(true);
return;
}
@@ -103,8 +103,8 @@ void HeaderItem::irefresh()
|| mMsgBase->isImportant() || mMsgBase->isTodo() || mMsgBase->isWatched() ) {
setOpen(true);
HeaderItem * topOfThread = this;
- while(topOfThread->parent())
- topOfThread = (HeaderItem*)topOfThread->parent();
+ while(topOfThread->tqparent())
+ topOfThread = (HeaderItem*)topOfThread->tqparent();
topOfThread->setOpenRecursive(true);
}
}
@@ -145,7 +145,7 @@ TQ_UINT32 HeaderItem::msgSerNum() const
// Update this item to summarise a new folder and message
-//Opens all children in the thread
+//Opens all tqchildren in the thread
void HeaderItem::setOpenRecursive( bool open )
{
if (open){
@@ -198,7 +198,7 @@ TQString HeaderItem::text( int col) const
tmp = headers->mDate.dateString( mMsgBase->date() );
} else if(col == headers->paintInfo()->sizeCol
&& headers->paintInfo()->showSize) {
- if ( mMsgBase->parent()->folderType() == KMFolderTypeImap ) {
+ if ( mMsgBase->tqparent()->folderType() == KMFolderTypeImap ) {
tmp = KIO::convertSize( mMsgBase->msgSizeServer() );
} else {
tmp = KIO::convertSize( mMsgBase->msgSize() );
@@ -212,8 +212,8 @@ void HeaderItem::setup()
widthChanged();
const int ph = KMHeaders::pixNew->height();
TQListView *v = listView();
- int h = QMAX( v->fontMetrics().height(), ph ) + 2*v->itemMargin();
- h = QMAX( h, TQApplication::globalStrut().height());
+ int h = TQMAX( v->fontMetrics().height(), ph ) + 2*v->itemMargin();
+ h = TQMAX( h, TQApplication::globalStrut().height());
if ( h % 2 > 0 )
h++;
setHeight( h );
@@ -228,7 +228,7 @@ TQPixmap HeaderItem::pixmapMerge( PixmapList pixmaps ) const
for ( PixmapList::ConstIterator it = pixmaps.begin();
it != pixmaps.end(); ++it ) {
width += (*it).width();
- height = QMAX( height, (*it).height() );
+ height = TQMAX( height, (*it).height() );
}
TQPixmap res( width, height );
@@ -309,7 +309,7 @@ const TQPixmap *HeaderItem::pixmap(int col) const
if ( msgBase->isWatched() ) pixmaps << *KMHeaders::pixWatched;
}
- if ( !headers->mPaintInfo.showStatus ) {
+ if ( !headers->mPaintInfo.showtqStatus ) {
const TQPixmap *pix = statusIcon(msgBase);
if ( pix ) pixmaps << *pix;
}
@@ -402,23 +402,23 @@ void HeaderItem::paintCell( TQPainter * p, const TQColorGroup & cg,
if ( mMsgBase->isTodo() ) {
color = const_cast<TQColor*>( &headers->paintInfo()->colTodo );
font = headers->todoFont();
- weight = QMAX( weight, font.weight() );
+ weight = TQMAX( weight, font.weight() );
}
if ( mMsgBase->isUnread() ) {
color = const_cast<TQColor*>( &headers->paintInfo()->colUnread );
font = headers->unreadFont();
- weight = QMAX( weight, font.weight() );
+ weight = TQMAX( weight, font.weight() );
}
if ( mMsgBase->isNew() ) {
color = const_cast<TQColor*>( &headers->paintInfo()->colNew );
font = headers->newFont();
- weight = QMAX( weight, font.weight() );
+ weight = TQMAX( weight, font.weight() );
}
if ( mMsgBase->isImportant() ) {
color = const_cast<TQColor*>( &headers->paintInfo()->colFlag );
font = headers->importantFont();
- weight = QMAX( weight, font.weight() );
+ weight = TQMAX( weight, font.weight() );
}
if ( column == headers->paintInfo()->dateCol ) {
font = headers->dateFont();
@@ -451,10 +451,10 @@ TQString HeaderItem::generate_key( KMHeaders *headers,
const KPaintInfo *paintInfo,
int sortOrder )
{
- // It appears, that TQListView in Qt-3.0 asks for the key
+ // It appears, that TQListView in TQt-3.0 asks for the key
// in TQListView::clear(), which is called from
// readSortOrder()
- if (!msg) return TQString::null;
+ if (!msg) return TQString();
int column = sortOrder & ((1 << 5) - 1);
TQString ret = TQChar( (char)sortOrder );
@@ -490,7 +490,7 @@ TQString HeaderItem::generate_key( KMHeaders *headers,
}
else if (column == paintInfo->sizeCol) {
TQString len;
- if ( msg->parent()->folderType() == KMFolderTypeImap )
+ if ( msg->tqparent()->folderType() == KMFolderTypeImap )
{
len = TQString::number( msg->msgSizeServer() );
} else {
@@ -603,7 +603,7 @@ int HeaderItem::compare( TQListViewItem *i, int col, bool ascending ) const
res = key( col, ascending ).compare( i->key( col, ascending ) );
} else if ( col == headers->paintInfo()->dateCol ) {
res = key( col, ascending ).compare( i->key( col, ascending ) );
- if (i->parent() && !ascending)
+ if (i->tqparent() && !ascending)
res = -res;
} else if ( col == headers->paintInfo()->subCol ||
col == headers->paintInfo()->senderCol ||